videocollection/videocollectionwrapper/src/videolistdatamodel_p.cpp
changeset 38 ff53afa8ad05
parent 37 4eb2df7f7cbe
child 41 229f037ce963
--- a/videocollection/videocollectionwrapper/src/videolistdatamodel_p.cpp	Fri Apr 30 09:52:11 2010 +0300
+++ b/videocollection/videocollectionwrapper/src/videolistdatamodel_p.cpp	Fri May 14 15:14:51 2010 +0300
@@ -15,7 +15,7 @@
 * 
 */
 
-// Version : %version: 37 %
+// Version : %version: 38 %
 
 // INCLUDE FILES
 #include <hbglobal.h>
@@ -451,8 +451,8 @@
     // signal that album has been updated
     emit q_ptr->albumChanged();
 
-    // signal that model is ready
-    emit q_ptr->modelReady();
+    // signal that model has changed.
+    emit q_ptr->modelChanged();
 }
 
 
@@ -497,9 +497,8 @@
     {
         q_ptr->beginInsertRows(QModelIndex(), startIndex, endIndex);
         q_ptr->endInsertRows();
+        emit q_ptr->modelChanged();
     }
-
-	emit q_ptr->modelReady();
 }
 
 // -----------------------------------------------------------------------------
@@ -890,4 +889,13 @@
     }
 }
 
+// -----------------------------------------------------------------------------
+// listCompleteSlot 
+// -----------------------------------------------------------------------------
+//
+void VideoListDataModelPrivate::listCompleteSlot()
+{
+    emit q_ptr->modelReady();
+}
+
 // End of file